@@ -15,81 +15,87 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  *          Lucas Rocha <lucasr@im.ufba.br>
  */
 
+#include "config.h"
+
 #include "option.h"
 #include <time.h>
+#include <stdlib.h>
+#include <string.h>
 
 /* General Options */
-gchar   *zenity_general_dialog_title;
-gchar   *zenity_general_window_icon;
-int      zenity_general_width;
-int      zenity_general_height;
-gchar   *zenity_general_dialog_text;
-gchar   *zenity_general_separator;
-gboolean zenity_general_editable;
-gchar   *zenity_general_uri;
+static gchar   *zenity_general_dialog_title;
+static gchar   *zenity_general_window_icon;
+static int      zenity_general_width;
+static int      zenity_general_height;
+static gchar   *zenity_general_dialog_text;
+static gchar   *zenity_general_separator;
+static gboolean zenity_general_multiple;
+static gboolean zenity_general_editable;
+static gchar   *zenity_general_uri;
+static gboolean zenity_general_dialog_no_wrap;
 
 /* Calendar Dialog Options */
-gboolean zenity_calendar_active;
-int      zenity_calendar_day;
-int      zenity_calendar_month;
-int      zenity_calendar_year;
-gchar   *zenity_calendar_date_format;
+static gboolean zenity_calendar_active;
+static int      zenity_calendar_day;
+static int      zenity_calendar_month;
+static int      zenity_calendar_year;
+static gchar   *zenity_calendar_date_format;
 
 /* Entry Dialog Options */
-gboolean zenity_entry_active;
-gchar   *zenity_entry_entry_text;
-gboolean zenity_entry_visible;
+static gboolean zenity_entry_active;
+static gchar   *zenity_entry_entry_text;
+static gboolean zenity_entry_hide_text;
 
 /* Error Dialog Options */
-gboolean zenity_error_active;
+static gboolean zenity_error_active;
 
 /* Info Dialog Options */
-gboolean zenity_info_active;
+static gboolean zenity_info_active;
 
 /* File Selection Dialog Options */
-gboolean zenity_file_active;
-gboolean zenity_file_multiple;
-gboolean zenity_file_directory;
-gboolean zenity_file_save;
+static gboolean zenity_file_active;
+static gboolean zenity_file_directory;
+static gboolean zenity_file_save;
 
 /* List Dialog Options */
-gboolean zenity_list_active;
-gchar  **zenity_list_columns;
-gboolean zenity_list_checklist;
-gboolean zenity_list_radiolist;
-gchar   *zenity_list_print_column;
+static gboolean zenity_list_active;
+static gchar  **zenity_list_columns;
+static gboolean zenity_list_checklist;
+static gboolean zenity_list_radiolist;
+static gchar   *zenity_list_print_column;
+static gchar   *zenity_list_hide_column;
 
 /* Notification Dialog Options */
-gboolean zenity_notification_active;
-gboolean zenity_notification_listen;
+static gboolean zenity_notification_active;
+static gboolean zenity_notification_listen;
 
 /* Progress Dialog Options */
-gboolean zenity_progress_active;
-int      zenity_progress_percentage;
-gboolean zenity_progress_pulsate;
-gboolean zenity_progress_auto_close;
+static gboolean zenity_progress_active;
+static int      zenity_progress_percentage;
+static gboolean zenity_progress_pulsate;
+static gboolean zenity_progress_auto_close;
 
 /* Question Dialog Options */
-gboolean zenity_question_active;
+static gboolean zenity_question_active;
 
 /* Text Dialog Options */
-gboolean zenity_text_active;
+static gboolean zenity_text_active;
 
 /* Warning Dialog Options */
-gboolean zenity_warning_active;
+static gboolean zenity_warning_active;
 
 /* Miscelaneus Options */
-gboolean zenity_misc_about;
-gboolean zenity_misc_version;
+static gboolean zenity_misc_about;
+static gboolean zenity_misc_version;
 
-GOptionEntry general_options[] = {
+static GOptionEntry general_options[] = {
   {
     "title",
     '\0',
@@ -131,7 +137,7 @@ GOptionEntry general_options[] = {
   }
 };
 
-GOptionEntry calendar_options[] = {
+static GOptionEntry calendar_options[] = {
   {
     "calendar",
     '\0',
@@ -144,7 +150,7 @@ GOptionEntry calendar_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -191,7 +197,7 @@ GOptionEntry calendar_options[] = {
   } 
 };
 
-GOptionEntry entry_options[] = {
+static GOptionEntry entry_options[] = {
   {
     "entry",
     '\0',
@@ -204,7 +210,7 @@ GOptionEntry entry_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -214,7 +220,7 @@ GOptionEntry entry_options[] = {
     "entry-text",
     '\0',
     0,
-    G_OPTION_ARG_STRING,
+    G_OPTION_ARG_STRING | G_OPTION_FLAG_NOALIAS,
     &zenity_entry_entry_text,
     N_("Set the entry text"),
     NULL
@@ -224,7 +230,7 @@ GOptionEntry entry_options[] = {
     '\0',
     0,
     G_OPTION_ARG_NONE,
-    &zenity_entry_visible,
+    &zenity_entry_hide_text,
     N_("Hide the entry text"),
     NULL
   },
@@ -234,7 +240,7 @@ GOptionEntry entry_options[] = {
 };
 
 
-GOptionEntry error_options[] = {
+static GOptionEntry error_options[] = {
   {
     "error",
     '\0',
@@ -247,18 +253,27 @@ GOptionEntry error_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
     NULL
   },
+  {
+    "no-wrap",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_general_dialog_no_wrap,
+    N_("Do not enable text wrapping"),
+    NULL
+  },
   { 
     NULL 
   } 
 };
 
-GOptionEntry info_options[] = {
+static GOptionEntry info_options[] = {
   {
     "info",
     '\0',
@@ -271,18 +286,27 @@ GOptionEntry info_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
     NULL
   },
+  {
+    "no-wrap",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_general_dialog_no_wrap,
+    N_("Do not enable text wrapping"),
+    NULL
+  },
   { 
     NULL 
   }
 };
 
-GOptionEntry file_selection_options[] = {
+static GOptionEntry file_selection_options[] = {
   {
     "file-selection",
     '\0',
@@ -295,7 +319,7 @@ GOptionEntry file_selection_options[] = {
   {
     "filename",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_FILENAME,
     &zenity_general_uri,
     N_("Set the filename"),
@@ -304,9 +328,9 @@ GOptionEntry file_selection_options[] = {
   {
     "multiple",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
-    &zenity_file_multiple,
+    &zenity_general_multiple,
     N_("Allow multiple files to be selected"),
     NULL
   },
@@ -331,7 +355,7 @@ GOptionEntry file_selection_options[] = {
   {
     "separator",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_separator,
     N_("Set output separator character"),
@@ -342,7 +366,7 @@ GOptionEntry file_selection_options[] = {
   } 
 };
 
-GOptionEntry list_options[] = {
+static GOptionEntry list_options[] = {
   {
     "list",
     '\0',
@@ -355,7 +379,7 @@ GOptionEntry list_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -397,10 +421,19 @@ GOptionEntry list_options[] = {
     N_("Set output separator character"),
     N_("SEPARATOR")
   },
+  {
+    "multiple",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_general_multiple,
+    N_("Allow multiple rows to be selected"),
+    NULL
+  },
   {
     "editable",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_editable,
     N_("Allow changes to text"),
@@ -415,12 +448,21 @@ GOptionEntry list_options[] = {
     N_("Print a specific column (Default is 1. 'ALL' can be used to print all columns)"),
     NULL
   },
+  {
+    "hide-column",
+    '\0',
+    0,
+    G_OPTION_ARG_STRING,
+    &zenity_list_hide_column,
+    N_("Hide a specific column"),
+    NULL
+  },
   { 
     NULL 
   } 
 };
 
-GOptionEntry notification_options[] = {
+static GOptionEntry notification_options[] = {
   {
     "notification",
     '\0',
@@ -433,7 +475,7 @@ GOptionEntry notification_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the notification text"),
@@ -453,7 +495,7 @@ GOptionEntry notification_options[] = {
   }
 };
 
-GOptionEntry progress_options[] = {
+static GOptionEntry progress_options[] = {
   {
     "progress",
     '\0',
@@ -466,7 +508,7 @@ GOptionEntry progress_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -505,7 +547,7 @@ GOptionEntry progress_options[] = {
   }
 };
 
-GOptionEntry question_options[] = {
+static GOptionEntry question_options[] = {
   {
     "question",
     '\0',
@@ -518,18 +560,27 @@ GOptionEntry question_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
     NULL
   },
+  {
+    "no-wrap",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_general_dialog_no_wrap,
+    N_("Do not enable text wrapping"),
+    NULL
+  },
   { 
     NULL 
   }
 };
 
-GOptionEntry text_options[] = {
+static GOptionEntry text_options[] = {
   {
     "text-info",
     '\0',
@@ -542,7 +593,7 @@ GOptionEntry text_options[] = {
   {
     "filename",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_FILENAME,
     &zenity_general_uri,
     N_("Open file"),
@@ -551,7 +602,7 @@ GOptionEntry text_options[] = {
   {
     "editable",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_editable,
     N_("Allow changes to text"),
@@ -562,7 +613,7 @@ GOptionEntry text_options[] = {
   }
 };
 
-GOptionEntry warning_options[] = {
+static GOptionEntry warning_options[] = {
   {
     "warning",
     '\0',
@@ -575,18 +626,27 @@ GOptionEntry warning_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
     NULL
   },
+  {
+    "no-wrap",
+    '\0',
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_NONE,
+    &zenity_general_dialog_no_wrap,
+    N_("Do not enable text wrapping"),
+    NULL
+  },
   { 
     NULL 
   }
 };
 
-GOptionEntry miscellaneous_options[] = {
+static GOptionEntry miscellaneous_options[] = {
   {
     "about",
     '\0',
@@ -610,10 +670,10 @@ GOptionEntry miscellaneous_options[] = {
   }
 };
 
-ZenityParsingOptions *results;
-GOptionContext *ctx;
+static ZenityParsingOptions *results;
+static GOptionContext *ctx;
 
-void
+static void
 zenity_option_init (void) {
 
   results = g_new0 (ZenityParsingOptions, 1);
@@ -653,11 +713,13 @@ zenity_option_free (void) {
     g_strfreev (zenity_list_columns);
   if (zenity_list_print_column)
     g_free (zenity_list_print_column);
+  if (zenity_list_hide_column)
+    g_free (zenity_list_hide_column);
 
   g_option_context_free (ctx);
 }
 
-void
+static void
 zenity_option_set_dialog_mode (gboolean is_active, ZenityDialogMode mode)  
 {
   if (is_active == TRUE) {
@@ -668,7 +730,7 @@ zenity_option_set_dialog_mode (gboolean is_active, ZenityDialogMode mode)
   }
 }
 
-gchar *
+static gchar *
 zenity_option_get_name (GOptionEntry *entries, gpointer arg_data)
 {
   int i;
@@ -681,17 +743,18 @@ zenity_option_get_name (GOptionEntry *entries, gpointer arg_data)
 }
 
 /* Error callback */
-void zenity_option_error_callback (GOptionContext *context,
-				   GOptionGroup   *group,
-				   gpointer        data,
-				   GError        **error)
+static void 
+zenity_option_error_callback (GOptionContext *context,
+                              GOptionGroup   *group,
+			      gpointer        data,
+			      GError        **error)
 {
   zenity_option_error (NULL, ERROR_SYNTAX);
 }
 
 /* Pre parse callbacks set the default option values */
 
-gboolean
+static gboolean
 zenity_general_pre_callback (GOptionContext *context,
 		             GOptionGroup   *group,
 		             gpointer	     data,
@@ -703,13 +766,15 @@ zenity_general_pre_callback (GOptionContext *context,
   zenity_general_height = -1;
   zenity_general_dialog_text = NULL;
   zenity_general_separator = g_strdup ("|");
+  zenity_general_multiple = FALSE;
   zenity_general_editable = FALSE;
   zenity_general_uri = NULL;
+  zenity_general_dialog_no_wrap = FALSE;
 
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_calendar_pre_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer        data,
@@ -724,7 +789,7 @@ zenity_calendar_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_entry_pre_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -732,12 +797,12 @@ zenity_entry_pre_callback (GOptionContext *context,
 {
   zenity_entry_active = FALSE;
   zenity_entry_entry_text = NULL;
-  zenity_entry_visible = FALSE;
+  zenity_entry_hide_text = FALSE;
 
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_error_pre_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -748,7 +813,7 @@ zenity_error_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_info_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -759,21 +824,20 @@ zenity_info_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_file_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
 		          GError        **error)
 {
   zenity_file_active = FALSE;
-  zenity_file_multiple = FALSE;
   zenity_file_directory = FALSE;
   zenity_file_save = FALSE;
 
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_list_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -784,11 +848,12 @@ zenity_list_pre_callback (GOptionContext *context,
   zenity_list_checklist = FALSE;
   zenity_list_radiolist = FALSE;
   zenity_list_print_column = NULL;
+  zenity_list_hide_column = NULL;
 
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_notification_pre_callback (GOptionContext *context,
 		                  GOptionGroup   *group,
 		                  gpointer	  data,
@@ -800,7 +865,7 @@ zenity_notification_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_progress_pre_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -814,7 +879,7 @@ zenity_progress_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_question_pre_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -825,7 +890,7 @@ zenity_question_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_text_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -836,7 +901,7 @@ zenity_text_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_warning_pre_callback (GOptionContext *context,
 		             GOptionGroup   *group,
 		             gpointer	     data,
@@ -847,7 +912,7 @@ zenity_warning_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_misc_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -862,7 +927,7 @@ zenity_misc_pre_callback (GOptionContext *context,
 /* Post parse callbacks assign the option values to
    parsing result and makes some post condition tests */
 
-gboolean
+static gboolean
 zenity_general_post_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -876,14 +941,12 @@ zenity_general_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_calendar_post_callback (GOptionContext *context,
 		               GOptionGroup   *group,
 		               gpointer	       data,
 		               GError        **error)
 {
-  int i;
-
   zenity_option_set_dialog_mode (zenity_calendar_active, MODE_CALENDAR);
 
   if (results->mode == MODE_CALENDAR) {
@@ -930,7 +993,7 @@ zenity_calendar_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_entry_post_callback (GOptionContext *context,
 		            GOptionGroup   *group,
 		            gpointer	    data,
@@ -941,21 +1004,21 @@ zenity_entry_post_callback (GOptionContext *context,
   if (results->mode == MODE_ENTRY) {
     results->entry_data->dialog_text = zenity_general_dialog_text;
     results->entry_data->entry_text = zenity_entry_entry_text;
-    results->entry_data->visible = !zenity_entry_visible;
+    results->entry_data->hide_text= zenity_entry_hide_text;
   } else {
     if (zenity_entry_entry_text)
       zenity_option_error (zenity_option_get_name (entry_options, &zenity_entry_entry_text),
                            ERROR_SUPPORT);
     
-    if (zenity_entry_visible)
-      zenity_option_error (zenity_option_get_name (entry_options, &zenity_entry_visible),
+    if (zenity_entry_hide_text)
+      zenity_option_error (zenity_option_get_name (entry_options, &zenity_entry_hide_text),
                            ERROR_SUPPORT);
   }
     
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_error_post_callback (GOptionContext *context,
 		            GOptionGroup   *group,
 		            gpointer	    data,
@@ -966,12 +1029,13 @@ zenity_error_post_callback (GOptionContext *context,
   if (results->mode == MODE_ERROR) {
     results->msg_data->dialog_text = zenity_general_dialog_text;
     results->msg_data->mode = ZENITY_MSG_ERROR; 
+    results->msg_data->no_wrap = zenity_general_dialog_no_wrap; 
   }
     
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_info_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -982,12 +1046,13 @@ zenity_info_post_callback (GOptionContext *context,
   if (results->mode == MODE_INFO) {
     results->msg_data->dialog_text = zenity_general_dialog_text;
     results->msg_data->mode = ZENITY_MSG_INFO; 
+    results->msg_data->no_wrap = zenity_general_dialog_no_wrap; 
   }
   
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_file_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -997,15 +1062,11 @@ zenity_file_post_callback (GOptionContext *context,
 
   if (results->mode == MODE_FILE) {
     results->file_data->uri = zenity_general_uri;
-    results->file_data->multi = zenity_file_multiple;
+    results->file_data->multi = zenity_general_multiple;
     results->file_data->directory = zenity_file_directory;
     results->file_data->save = zenity_file_save;
     results->file_data->separator = zenity_general_separator;
   } else {
-    if (zenity_file_multiple)
-      zenity_option_error (zenity_option_get_name (file_selection_options, &zenity_file_multiple),
-                           ERROR_SUPPORT);
-
     if (zenity_file_directory)
       zenity_option_error (zenity_option_get_name (file_selection_options, &zenity_file_directory),
                            ERROR_SUPPORT);
@@ -1018,7 +1079,7 @@ zenity_file_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_list_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1042,8 +1103,10 @@ zenity_list_post_callback (GOptionContext *context,
     
     results->tree_data->checkbox = zenity_list_checklist;
     results->tree_data->radiobox = zenity_list_radiolist;
+    results->tree_data->multi = zenity_general_multiple;
     results->tree_data->editable = zenity_general_editable;
     results->tree_data->print_column = zenity_list_print_column;
+    results->tree_data->hide_column = zenity_list_hide_column;
     results->tree_data->separator = zenity_general_separator;
   } else {
     if (zenity_list_columns)
@@ -1061,12 +1124,16 @@ zenity_list_post_callback (GOptionContext *context,
     if (zenity_list_print_column)
       zenity_option_error (zenity_option_get_name (list_options, &zenity_list_print_column),
                            ERROR_SUPPORT);
+
+    if (zenity_list_hide_column)
+      zenity_option_error (zenity_option_get_name (list_options, &zenity_list_hide_column),
+                           ERROR_SUPPORT);
   }
     
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_notification_post_callback (GOptionContext *context,
 		                   GOptionGroup   *group,
 		                   gpointer	   data,
@@ -1086,7 +1153,7 @@ zenity_notification_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_progress_post_callback (GOptionContext *context,
 		               GOptionGroup   *group,
 		               gpointer	       data,
@@ -1116,7 +1183,7 @@ zenity_progress_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_question_post_callback (GOptionContext *context,
 		               GOptionGroup   *group,
 		               gpointer	       data,
@@ -1128,12 +1195,13 @@ zenity_question_post_callback (GOptionContext *context,
   if (results->mode == MODE_QUESTION) {
     results->msg_data->dialog_text = zenity_general_dialog_text;
     results->msg_data->mode = ZENITY_MSG_QUESTION;
+    results->msg_data->no_wrap = zenity_general_dialog_no_wrap; 
   }
 
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_text_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1149,7 +1217,7 @@ zenity_text_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_warning_post_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -1160,12 +1228,13 @@ zenity_warning_post_callback (GOptionContext *context,
   if (results->mode == MODE_WARNING) {
     results->msg_data->dialog_text = zenity_general_dialog_text;
     results->msg_data->mode = ZENITY_MSG_WARNING;
+    results->msg_data->no_wrap = zenity_general_dialog_no_wrap; 
   }
 
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_misc_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1177,7 +1246,7 @@ zenity_misc_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-GOptionContext *
+static GOptionContext *
 zenity_create_context (void) 
 {
   GOptionContext *tmp_ctx;
@@ -1193,6 +1262,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_general_pre_callback, zenity_general_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds calendar option entries */
@@ -1203,6 +1273,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_calendar_pre_callback, zenity_calendar_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds entry option entries */
@@ -1213,6 +1284,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_entry_pre_callback, zenity_entry_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds error option entries */
@@ -1223,6 +1295,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_error_pre_callback, zenity_error_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds info option entries */
@@ -1233,6 +1306,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_info_pre_callback, zenity_info_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds file selection option entries */
@@ -1243,6 +1317,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_file_pre_callback, zenity_file_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds list option entries */
@@ -1253,6 +1328,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_list_pre_callback, zenity_list_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds notification option entries */
@@ -1263,6 +1339,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_notification_pre_callback, zenity_notification_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds progress option entries */
@@ -1273,6 +1350,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_progress_pre_callback, zenity_progress_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds question option entries */
@@ -1283,6 +1361,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_question_pre_callback, zenity_question_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds warning option entries */
@@ -1293,6 +1372,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_warning_pre_callback, zenity_warning_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds text option entries */
@@ -1303,6 +1383,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_text_pre_callback, zenity_text_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds misc option entries */
@@ -1313,10 +1394,12 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_misc_pre_callback, zenity_misc_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds gtk option entries */
   a_group = gtk_get_option_group(TRUE);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Enable help options */
@@ -1331,7 +1414,7 @@ zenity_option_error (gchar *string, ZenityError error)
 {
   switch (error) {
     case ERROR_SYNTAX:
-      g_printerr (_("Syntax error\n"));
+      g_printerr (_("This option is not available. Please see --help for all possible usages.\n"));
       zenity_option_free ();
       exit (-1);
     case ERROR_SUPPORT:
@@ -1369,6 +1452,10 @@ zenity_option_parse (gint argc, gchar **argv)
     if (results->mode != MODE_LIST && results->mode != MODE_FILE)
       zenity_option_error (zenity_option_get_name (list_options, &zenity_general_separator), ERROR_SUPPORT);
   
+  if (zenity_general_multiple)
+    if (results->mode != MODE_FILE && results->mode != MODE_LIST)
+      zenity_option_error (zenity_option_get_name (list_options, &zenity_general_multiple), ERROR_SUPPORT);
+
   if (zenity_general_editable)
     if (results->mode != MODE_TEXTINFO && results->mode != MODE_LIST)
       zenity_option_error (zenity_option_get_name (list_options, &zenity_general_editable), ERROR_SUPPORT);
@@ -1377,5 +1464,9 @@ zenity_option_parse (gint argc, gchar **argv)
     if (results->mode != MODE_FILE && results->mode != MODE_TEXTINFO)
       zenity_option_error (zenity_option_get_name (text_options, &zenity_general_uri), ERROR_SUPPORT);
   
+  if (zenity_general_dialog_no_wrap)
+    if (results->mode != MODE_INFO && results->mode != MODE_ERROR && results->mode != MODE_QUESTION && results->mode != MODE_WARNING)
+      zenity_option_error (zenity_option_get_name (text_options, &zenity_general_dialog_no_wrap), ERROR_SUPPORT);
+  
   return results; 
 }
